@@ -10,18 +10,18 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/sirupsen/logrus"
+	"github.com/spf13/cobra"
+
 	"github.com/lima-vm/lima/cmd/limactl/editflags"
 	"github.com/lima-vm/lima/pkg/editutil"
 	"github.com/lima-vm/lima/pkg/instance"
-	"github.com/lima-vm/lima/pkg/limatmpl"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	networks "github.com/lima-vm/lima/pkg/networks/reconcile"
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/uiutil"
 	"github.com/lima-vm/lima/pkg/yqutil"
-	"github.com/sirupsen/logrus"
-	"github.com/spf13/cobra"
 )
 
 func newEditCommand() *cobra.Command {
@@ -33,7 +33,7 @@ func newEditCommand() *cobra.Command {
 		ValidArgsFunction: editBashComplete,
 		GroupID:           basicCommand,
 	}
-	editflags.RegisterEdit(editCommand)
+	editflags.RegisterEdit(editCommand, "")
 	return editCommand
 }
 
@@ -46,33 +46,28 @@ func editAction(cmd *cobra.Command, args []string) error {
 	var filePath string
 	var err error
 	var inst *store.Instance
-	switch {
-	case limatmpl.SeemsYAMLPath(arg):
+
+	if arg == "" {
+		arg = DefaultInstanceName
+	}
+	if err := store.ValidateInstName(arg); err == nil {
+		inst, err = store.Inspect(arg)
+		if err != nil {
+			if errors.Is(err, os.ErrNotExist) {
+				return fmt.Errorf("instance %q not found", arg)
+			}
+			return err
+		}
+		if inst.Status == store.StatusRunning {
+			return errors.New("cannot edit a running instance")
+		}
+		filePath = filepath.Join(inst.Dir, filenames.LimaYAML)
+	} else {
 		// absolute path is required for `limayaml.Validate`
 		filePath, err = filepath.Abs(arg)
 		if err != nil {
 			return err
 		}
-	default:
-		var instName string
-		if arg != "" {
-			instName = arg
-		} else {
-			instName = DefaultInstanceName
-		}
-
-		inst, err = store.Inspect(instName)
-		if err != nil {
-			if errors.Is(err, os.ErrNotExist) {
-				return fmt.Errorf("instance %q not found", instName)
-			}
-			return err
-		}
-
-		if inst.Status == store.StatusRunning {
-			return errors.New("cannot edit a running instance")
-		}
-		filePath = filepath.Join(inst.Dir, filenames.LimaYAML)
 	}
 
 	yContent, err := os.ReadFile(filePath)
@@ -123,13 +118,13 @@ func editAction(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	if err := limayaml.Validate(y, true); err != nil {
-		rejectedYAML := "lima.REJECTED.yaml"
-		if writeErr := os.WriteFile(rejectedYAML, yBytes, 0o644); writeErr != nil {
-			return fmt.Errorf("the YAML is invalid, attempted to save the buffer as %q but failed: %w: %w", rejectedYAML, writeErr, err)
-		}
-		// TODO: may need to support editing the rejected YAML
-		return fmt.Errorf("the YAML is invalid, saved the buffer as %q: %w", rejectedYAML, err)
+		return saveRejectedYAML(yBytes, err)
 	}
+
+	if err := limayaml.ValidateAgainstLatestConfig(yBytes, yContent); err != nil {
+		return saveRejectedYAML(yBytes, err)
+	}
+
 	if err := os.WriteFile(filePath, yBytes, 0o644); err != nil {
 		return err
 	}
@@ -176,3 +171,13 @@ func askWhetherToStart() (bool, error) {
 func editBashComplete(cmd *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
 	return bashCompleteInstanceNames(cmd)
 }
+
+// saveRejectedYAML writes the rejected config and returns an error.
+func saveRejectedYAML(y []byte, origErr error) error {
+	rejectedYAML := "lima.REJECTED.yaml"
+	if writeErr := os.WriteFile(rejectedYAML, y, 0o644); writeErr != nil {
+		return fmt.Errorf("the YAML is invalid, attempted to save the buffer as %q but failed: %w", rejectedYAML, errors.Join(writeErr, origErr))
+	}
+	// TODO: may need to support editing the rejected YAML
+	return fmt.Errorf("the YAML is invalid, saved the buffer as %q: %w", rejectedYAML, origErr)
+}
