@@ -4,6 +4,7 @@
 package editflags
 
 import (
+	"errors"
 	"fmt"
 	"math/bits"
 	"runtime"
@@ -17,11 +18,7 @@ import (
 )
 
 // RegisterEdit registers flags related to in-place YAML modification, for `limactl edit`.
-func RegisterEdit(cmd *cobra.Command) {
-	registerEdit(cmd, "")
-}
-
-func registerEdit(cmd *cobra.Command, commentPrefix string) {
+func RegisterEdit(cmd *cobra.Command, commentPrefix string) {
 	flags := cmd.Flags()
 
 	flags.Int("cpus", 0, commentPrefix+"Number of CPUs") // Similar to colima's --cpu, but the flag name is slightly different (cpu vs cpus)
@@ -45,6 +42,7 @@ func registerEdit(cmd *cobra.Command, commentPrefix string) {
 	})
 
 	flags.StringSlice("mount", nil, commentPrefix+"Directories to mount, suffix ':w' for writable (Do not specify directories that overlap with the existing mounts)") // colima-compatible
+	flags.Bool("mount-none", false, commentPrefix+"Remove all mounts")
 
 	flags.String("mount-type", "", commentPrefix+"Mount type (reverse-sshfs, 9p, virtiofs)") // Similar to colima's --mount-type=(sshfs|9p|virtiofs), but "reverse-sshfs" is Lima is called "sshfs" in colima
 	_ = cmd.RegisterFlagCompletionFunc("mount-type", func(*cobra.Command, []string, string) ([]string, cobra.ShellCompDirective) {
@@ -75,7 +73,7 @@ func registerEdit(cmd *cobra.Command, commentPrefix string) {
 
 // RegisterCreate registers flags related to in-place YAML modification, for `limactl create`.
 func RegisterCreate(cmd *cobra.Command, commentPrefix string) {
-	registerEdit(cmd, commentPrefix)
+	RegisterEdit(cmd, commentPrefix)
 	flags := cmd.Flags()
 
 	flags.String("arch", "", commentPrefix+"Machine architecture (x86_64, aarch64, riscv64, armv7l, s390x, ppc64le)") // colima-compatible
@@ -84,7 +82,7 @@ func RegisterCreate(cmd *cobra.Command, commentPrefix string) {
 	})
 
 	flags.String("containerd", "", commentPrefix+"containerd mode (user, system, user+system, none)")
-	_ = cmd.RegisterFlagCompletionFunc("vm-type", func(*cobra.Command, []string, string) ([]string, cobra.ShellCompDirective) {
+	_ = cmd.RegisterFlagCompletionFunc("containerd", func(*cobra.Command, []string, string) ([]string, cobra.ShellCompDirective) {
 		return []string{"user", "system", "user+system", "none"}, cobra.ShellCompDirectiveNoFileComp
 	})
 
@@ -157,6 +155,21 @@ func YQExpressions(flags *flag.FlagSet, newInstance bool) ([]string, error) {
 			false,
 			false,
 		},
+		{
+			"mount-none",
+			func(_ *flag.Flag) (string, error) {
+				ss, err := flags.GetStringSlice("mount")
+				if err != nil {
+					return "", err
+				}
+				if len(ss) > 0 {
+					return "", errors.New("flag `--mount-none` conflicts with `--mount`")
+				}
+				return ".mounts = null", nil
+			},
+			false,
+			false,
+		},
 		{"mount-type", d(".mountType = %q"), false, false},
 		{"mount-inotify", d(".mountInotify = %s"), false, true},
 		{"mount-writable", d(".mounts[].writable = %s"), false, false},
