@@ -49,6 +49,7 @@ declare -A CHECKS=(
 	# snapshot tests are too flaky (especially with archlinux)
 	["snapshot-online"]=""
 	["snapshot-offline"]=""
+	["clone"]=""
 	["port-forwards"]="1"
 	["vmnet"]=""
 	["disk"]=""
@@ -60,6 +61,11 @@ declare -A CHECKS=(
 )
 
 case "$NAME" in
+"default")
+	# CI failure:
+	# "[hostagent] failed to confirm whether /c/Users/runneradmin [remote] is successfully mounted"
+	[ "${OS_HOST}" = "Msys" ] && CHECKS["mount-home"]=
+	;;
 "alpine"*)
 	WARNING "Alpine does not support systemd"
 	CHECKS["systemd"]=
@@ -80,6 +86,7 @@ case "$NAME" in
 	CHECKS["disk"]=1
 	CHECKS["snapshot-online"]="1"
 	CHECKS["snapshot-offline"]="1"
+	CHECKS["clone"]="1"
 	CHECKS["mount-path-with-spaces"]="1"
 	CHECKS["provision-data"]="1"
 	CHECKS["param-env-variables"]="1"
@@ -247,6 +254,13 @@ limactl shell "$NAME" bash -c "echo 'foo \"bar\"'"
 
 if [[ -n ${CHECKS["systemd"]} ]]; then
 	set -x
+	# agetty segfaults on Ubuntu 25.04 (x86_64)
+	# > __strncmp_evex () at ../sysdeps/x86_64/multiarch/strcmp-evex.S:316
+	# Should be fixed in Ubuntu 25.10 with util-linux >= 2.41
+	# https://github.com/lima-vm/lima/pull/3643#issuecomment-3006788732
+	if limactl shell "$NAME" systemctl -q is-failed serial-getty@ttyS0.service; then
+		limactl shell "$NAME" sudo systemctl reset-failed serial-getty@ttyS0.service
+	fi
 	if ! limactl shell "$NAME" systemctl is-system-running --wait; then
 		ERROR '"systemctl is-system-running" failed'
 		diagnose "$NAME"
@@ -367,6 +381,15 @@ if [[ -n ${CHECKS["port-forwards"]} ]]; then
 				limactl shell "$NAME" $sudo $CONTAINER_ENGINE rm -f nginx
 			fi
 		fi
+		if [[ ${NAME} != "alpine"* && ${NAME} != "wsl2"* ]] && command -v w3m >/dev/null; then
+			INFO "Testing https://github.com/lima-vm/lima/issues/3685 ([gRPC portfwd] client connection is not closed immediately when server closed the connection)"
+			# Skip the test on Alpine, as systemd-run is missing
+			# Skip the test on WSL2, as port forwarding is half broken https://github.com/lima-vm/lima/pull/3686#issuecomment-3034842616
+			limactl shell "$NAME" systemd-run --user python3 -m http.server 3685
+			# curl is not enough to reproduce https://github.com/lima-vm/lima/issues/3685
+			# `w3m -dump` exits with status code 0 even on "Can't load" error.
+			timeout 30s bash -euxc "until w3m -dump http://localhost:3685 | grep -v \"w3m: Can't load\"; do sleep 3; done"
+		fi
 	fi
 	set +x
 fi
@@ -515,6 +538,16 @@ if [[ -n ${CHECKS["snapshot-offline"]} ]]; then
 	limactl snapshot delete "$NAME" --tag snap2
 	limactl start "$NAME"
 fi
+if [[ -n ${CHECKS["clone"]} ]]; then
+	INFO "Testing cloning"
+	limactl stop "$NAME"
+	sleep 3
+	# [hostagent] could not attach disk \"data\", in use by instance \"test-misc-clone\"
+	limactl clone --set '.additionalDisks = null' "$NAME" "${NAME}-clone"
+	limactl start "${NAME}-clone"
+	[ "$(limactl shell "${NAME}-clone" hostname)" = "lima-${NAME}-clone" ]
+	limactl start "$NAME"
+fi
 
 if [[ $NAME == "fedora" && "$(limactl ls --json "$NAME" | jq -r .vmType)" == "vz" ]]; then
 	"${scriptdir}"/test-selinux.sh "$NAME"
