@@ -1,5 +1,8 @@
 #!/bin/bash
 
+# SPDX-FileCopyrightText: Copyright The Lima Authors
+# SPDX-License-Identifier: Apache-2.0
+
 set -eux -o pipefail
 
 if [ "$LIMA_CIDATA_ROSETTA_ENABLED" != "true" ]; then
@@ -8,7 +11,7 @@ fi
 
 if [ -f /etc/alpine-release ]; then
 	rc-service procfs start --ifnotstarted
-	rc-service qemu-binfmt stop --ifstarted
+	rc-service qemu-binfmt stop --ifexists --ifstarted
 fi
 
 binfmt_entry=/proc/sys/fs/binfmt_misc/rosetta
