@@ -11,9 +11,8 @@ import (
 	"io/fs"
 	"path"
 
+	"github.com/lima-vm/lima/pkg/identifiers"
 	"github.com/lima-vm/lima/pkg/iso9660util"
-
-	"github.com/containerd/containerd/identifiers"
 	"github.com/lima-vm/lima/pkg/textutil"
 )
 
