@@ -14,13 +14,14 @@ import (
 
 	"github.com/elastic/go-libaudit/v2"
 	"github.com/elastic/go-libaudit/v2/auparse"
+	"github.com/sirupsen/logrus"
+	"google.golang.org/protobuf/types/known/timestamppb"
+
 	"github.com/lima-vm/lima/pkg/guestagent/api"
 	"github.com/lima-vm/lima/pkg/guestagent/iptables"
 	"github.com/lima-vm/lima/pkg/guestagent/kubernetesservice"
 	"github.com/lima-vm/lima/pkg/guestagent/procnettcp"
 	"github.com/lima-vm/lima/pkg/guestagent/timesync"
-	"github.com/sirupsen/logrus"
-	"google.golang.org/protobuf/types/known/timestamppb"
 )
 
 func New(newTicker func() (<-chan time.Time, func()), iptablesIdle time.Duration) (Agent, error) {
@@ -168,7 +169,7 @@ func comparePorts(old, neww []*api.IPPort) (added, removed []*api.IPPort) {
 			}
 		}
 	}
-	return
+	return added, removed
 }
 
 func (a *agent) collectEvent(ctx context.Context, st eventState) (*api.Event, eventState) {
@@ -190,9 +191,8 @@ func (a *agent) collectEvent(ctx context.Context, st eventState) (*api.Event, ev
 
 func isEventEmpty(ev *api.Event) bool {
 	empty := &api.Event{}
-	copied := ev
-	copied.Time = nil
-	return reflect.DeepEqual(empty, copied)
+	empty.Time = ev.Time
+	return reflect.DeepEqual(empty, ev)
 }
 
 func (a *agent) Events(ctx context.Context, ch chan *api.Event) {
