@@ -12,6 +12,7 @@ import (
 )
 
 func TestParseTCP(t *testing.T) {
+	const isBE = false
 	procNetTCP := `  sl  local_address rem_address   st tx_queue rx_queue tr tm->when retrnsmt   uid  timeout inode                                                     
    0: 0100007F:8AEF 00000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 28152 1 0000000000000000 100 0 0 10 0                     
    1: 0103000A:0035 00000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 31474 1 0000000000000000 100 0 0 10 5                     
@@ -20,7 +21,7 @@ func TestParseTCP(t *testing.T) {
    4: 0100007F:053A 00000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 31430 1 0000000000000000 100 0 0 10 0                     
    5: 0B3CA8C0:0016 690AA8C0:F705 01 00000000:00000000 02:00028D8B 00000000     0        0 32989 4 0000000000000000 20 4 31 10 19
 `
-	entries, err := Parse(strings.NewReader(procNetTCP), TCP)
+	entries, err := ParseWithEndian(strings.NewReader(procNetTCP), TCP, isBE)
 	assert.NilError(t, err)
 	t.Log(entries)
 
@@ -34,9 +35,10 @@ func TestParseTCP(t *testing.T) {
 }
 
 func TestParseTCP6(t *testing.T) {
+	const isBE = false
 	procNetTCP := `  sl  local_address                         remote_address                        st tx_queue rx_queue tr tm->when retrnsmt   uid  timeout inode
 	   0: 000080FE00000000FF57A6705DC771FE:0050 00000000000000000000000000000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 850222 1 0000000000000000 100 0 0 10 0`
-	entries, err := Parse(strings.NewReader(procNetTCP), TCP6)
+	entries, err := ParseWithEndian(strings.NewReader(procNetTCP), TCP6, isBE)
 	assert.NilError(t, err)
 	t.Log(entries)
 
@@ -46,12 +48,13 @@ func TestParseTCP6(t *testing.T) {
 }
 
 func TestParseTCP6Zero(t *testing.T) {
+	const isBE = false
 	procNetTCP := `  sl  local_address                         remote_address                        st tx_queue rx_queue tr tm->when retrnsmt   uid  timeout inode
    0: 00000000000000000000000000000000:0016 00000000000000000000000000000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 33825 1 0000000000000000 100 0 0 10 0
    1: 00000000000000000000000000000000:006F 00000000000000000000000000000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 26772 1 0000000000000000 100 0 0 10 0
    2: 00000000000000000000000000000000:0050 00000000000000000000000000000000:0000 0A 00000000:00000000 00:00000000 00000000     0        0 1210901 1 0000000000000000 100 0 0 10 0
 `
-	entries, err := Parse(strings.NewReader(procNetTCP), TCP6)
+	entries, err := ParseWithEndian(strings.NewReader(procNetTCP), TCP6, isBE)
 	assert.NilError(t, err)
 	t.Log(entries)
 
@@ -61,13 +64,14 @@ func TestParseTCP6Zero(t *testing.T) {
 }
 
 func TestParseUDP(t *testing.T) {
+	const isBE = false
 	procNetTCP := `   sl  local_address rem_address   st tx_queue rx_queue tr tm->when retrnsmt   uid  timeout inode ref pointer drops            
   716: 3600007F:0035 00000000:0000 07 00000000:00000000 00:00000000 00000000   991        0 2964 2 0000000000000000 0          
   716: 3500007F:0035 00000000:0000 07 00000000:00000000 00:00000000 00000000   991        0 2962 2 0000000000000000 0          
   731: 0369A8C0:0044 00000000:0000 07 00000000:00000000 00:00000000 00000000   998        0 29132 2 0000000000000000 0         
   731: 0F05A8C0:0044 00000000:0000 07 00000000:00000000 00:00000000 00000000   998        0 4049 2 0000000000000000 0          
  1768: 00000000:1451 00000000:0000 07 00000000:00000000 00:00000000 00000000   502        0 28364 2 0000000000000000 0  `
-	entries, err := Parse(strings.NewReader(procNetTCP), UDP)
+	entries, err := ParseWithEndian(strings.NewReader(procNetTCP), UDP, isBE)
 	assert.NilError(t, err)
 	t.Log(entries)
 
@@ -79,6 +83,7 @@ func TestParseUDP(t *testing.T) {
 func TestParseAddress(t *testing.T) {
 	tests := []struct {
 		input             string
+		bigEndian         bool
 		expectedIP        net.IP
 		expectedPort      uint16
 		expectedErrSubstr string
@@ -88,16 +93,34 @@ func TestParseAddress(t *testing.T) {
 			expectedIP:   net.IPv4(127, 0, 0, 1),
 			expectedPort: 80,
 		},
+		{
+			input:        "7F000001:0050",
+			bigEndian:    true,
+			expectedIP:   net.IPv4(127, 0, 0, 1),
+			expectedPort: 80,
+		},
 		{
 			input:        "000080FE00000000FF57A6705DC771FE:0050",
 			expectedIP:   net.ParseIP("fe80::70a6:57ff:fe71:c75d"),
 			expectedPort: 80,
 		},
+		{
+			input:        "FE8000000000000070A657FFFE71C75D:0050",
+			bigEndian:    true,
+			expectedIP:   net.ParseIP("fe80::70a6:57ff:fe71:c75d"),
+			expectedPort: 80,
+		},
 		{
 			input:        "00000000000000000000000000000000:0050",
 			expectedIP:   net.IPv6zero,
 			expectedPort: 80,
 		},
+		{
+			input:        "00000000000000000000000000000000:0050",
+			bigEndian:    true,
+			expectedIP:   net.IPv6zero,
+			expectedPort: 80,
+		},
 		{
 			input:             "0100007F",
 			expectedErrSubstr: `unparsable address "0100007F"`,
@@ -126,7 +149,7 @@ func TestParseAddress(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.input, func(t *testing.T) {
-			ip, port, err := ParseAddress(test.input)
+			ip, port, err := ParseAddressWithEndian(test.input, test.bigEndian)
 			if test.expectedErrSubstr != "" {
 				assert.ErrorContains(t, err, test.expectedErrSubstr)
 			} else {
