@@ -19,6 +19,9 @@ import (
 	"sync"
 	"time"
 
+	"github.com/lima-vm/sshocker/pkg/ssh"
+	"github.com/sethvargo/go-password/password"
+	"github.com/sirupsen/logrus"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
@@ -31,7 +34,7 @@ import (
 	hostagentapi "github.com/lima-vm/lima/pkg/hostagent/api"
 	"github.com/lima-vm/lima/pkg/hostagent/dns"
 	"github.com/lima-vm/lima/pkg/hostagent/events"
-	"github.com/lima-vm/lima/pkg/identifierutil"
+	"github.com/lima-vm/lima/pkg/instance/hostname"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/networks"
 	"github.com/lima-vm/lima/pkg/osutil"
@@ -39,9 +42,6 @@ import (
 	"github.com/lima-vm/lima/pkg/sshutil"
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
-	"github.com/lima-vm/sshocker/pkg/ssh"
-	"github.com/sethvargo/go-password/password"
-	"github.com/sirupsen/logrus"
 )
 
 type HostAgent struct {
@@ -53,7 +53,7 @@ type HostAgent struct {
 	instName          string
 	instSSHAddress    string
 	sshConfig         *ssh.SSHConfig
-	portForwarder     *portForwarder // legacy SSH port forwarder (deprecated)
+	portForwarder     *portForwarder // legacy SSH port forwarder
 	grpcPortForwarder *portfwd.Forwarder
 
 	onClose []func() error // LIFO
@@ -131,13 +131,9 @@ func New(instName string, stdout io.Writer, signalCh chan os.Signal, opts ...Opt
 		}
 	}
 
-	baseDriver := driver.BaseDriver{
-		Instance:     inst,
-		SSHLocalPort: sshLocalPort,
-	}
-	limaDriver := driverutil.CreateTargetDriverInstance(&baseDriver)
-	vSockPort := baseDriver.VSockPort
-	virtioPort := baseDriver.VirtioPort
+	limaDriver := driverutil.CreateTargetDriverInstance(inst, sshLocalPort)
+	vSockPort := limaDriver.VSockPort()
+	virtioPort := limaDriver.VirtioPort()
 
 	if err := cidata.GenerateCloudConfig(inst.Dir, instName, inst.Config); err != nil {
 		return nil, err
@@ -222,14 +218,11 @@ func writeSSHConfigFile(sshPath, instName, instDir, instSSHAddress string, sshLo
 	if instDir == "" {
 		return fmt.Errorf("directory is unknown for the instance %q", instName)
 	}
-	var b bytes.Buffer
-	if _, err := fmt.Fprintf(&b, `# This SSH config file can be passed to 'ssh -F'.
+	b := bytes.NewBufferString(`# This SSH config file can be passed to 'ssh -F'.
 # This file is created by Lima, but not used by Lima itself currently.
 # Modifications to this file will be lost on restarting the Lima instance.
-`); err != nil {
-		return err
-	}
-	if err := sshutil.Format(&b, sshPath, instName, sshutil.FormatConfig,
+`)
+	if err := sshutil.Format(b, sshPath, instName, sshutil.FormatConfig,
 		append(sshOpts,
 			fmt.Sprintf("Hostname=%s", instSSHAddress),
 			fmt.Sprintf("Port=%d", sshLocalPort),
@@ -288,8 +281,8 @@ func (a *HostAgent) Run(ctx context.Context) error {
 	if limayaml.FirstUsernetIndex(a.instConfig) == -1 && *a.instConfig.HostResolver.Enabled {
 		hosts := a.instConfig.HostResolver.Hosts
 		hosts["host.lima.internal"] = networks.SlirpGateway
-		hostname := identifierutil.HostnameFromInstName(a.instName) // TODO: support customization
-		hosts[hostname] = networks.SlirpIPAddress
+		name := hostname.FromInstName(a.instName) // TODO: support customization
+		hosts[name] = networks.SlirpIPAddress
 		srvOpts := dns.ServerOptions{
 			UDPPort: a.udpDNSLocalPort,
 			TCPPort: a.tcpDNSLocalPort,
@@ -659,7 +652,7 @@ func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client *guestag
 		// - v1.1.0-beta.0: false
 		useSSHFwd := false
 		if envVar := os.Getenv("LIMA_SSH_PORT_FORWARDER"); envVar != "" {
-			b, err := strconv.ParseBool(os.Getenv("LIMA_SSH_PORT_FORWARDER"))
+			b, err := strconv.ParseBool(envVar)
 			if err != nil {
 				logrus.WithError(err).Warnf("invalid LIMA_SSH_PORT_FORWARDER value %q", envVar)
 			} else {
@@ -667,7 +660,6 @@ func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client *guestag
 			}
 		}
 		if useSSHFwd {
-			logrus.Warn("LIMA_SSH_PORT_FORWARDER is deprecated")
 			a.portForwarder.OnEvent(ctx, ev)
 		} else {
 			a.grpcPortForwarder.OnEvent(ctx, client, ev)
@@ -761,6 +753,7 @@ func forwardSSH(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local,
 		}
 	}
 	cmd := exec.CommandContext(ctx, sshConfig.Binary(), args...)
+	logrus.Debugf("Running %q", cmd)
 	if out, err := cmd.Output(); err != nil {
 		if verb == verbForward && strings.HasPrefix(local, "/") {
 			if reverse {
