@@ -24,13 +24,12 @@ import (
 	"github.com/coreos/go-semver/semver"
 	"github.com/docker/go-units"
 	"github.com/goccy/go-yaml"
-	"github.com/lima-vm/lima/pkg/ioutilx"
-	"github.com/lima-vm/lima/pkg/version"
 	"github.com/pbnjay/memory"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/sys/cpu"
 
-	"github.com/lima-vm/lima/pkg/identifierutil"
+	"github.com/lima-vm/lima/pkg/instance/hostname"
+	"github.com/lima-vm/lima/pkg/ioutilx"
 	"github.com/lima-vm/lima/pkg/localpathutil"
 	. "github.com/lima-vm/lima/pkg/must"
 	"github.com/lima-vm/lima/pkg/networks"
@@ -38,6 +37,7 @@ import (
 	"github.com/lima-vm/lima/pkg/ptr"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
+	"github.com/lima-vm/lima/pkg/version"
 	"github.com/lima-vm/lima/pkg/version/versionutil"
 )
 
@@ -135,26 +135,6 @@ func MACAddress(uniqueID string) string {
 	return hw.String()
 }
 
-func hostTimeZone() string {
-	// WSL2 will automatically set the timezone
-	if runtime.GOOS != "windows" {
-		tz, err := os.ReadFile("/etc/timezone")
-		if err == nil {
-			return strings.TrimSpace(string(tz))
-		}
-		zoneinfoFile, err := filepath.EvalSymlinks("/etc/localtime")
-		if err == nil {
-			for baseDir := filepath.Dir(zoneinfoFile); baseDir != "/"; baseDir = filepath.Dir(baseDir) {
-				if _, err = os.Stat(filepath.Join(baseDir, "Etc/UTC")); err == nil {
-					return strings.TrimPrefix(zoneinfoFile, baseDir+"/")
-				}
-			}
-			logrus.Warnf("could not locate zoneinfo directory from %q", zoneinfoFile)
-		}
-	}
-	return ""
-}
-
 func defaultCPUs() int {
 	const x = 4
 	if hostCPUs := runtime.NumCPU(); hostCPUs < x {
@@ -699,6 +679,12 @@ func FillDefault(y, d, o *LimaYAML, filePath string, warn bool) {
 	for _, f := range y.MountTypesUnsupported {
 		mountTypesUnsupported[f] = struct{}{}
 	}
+
+	if runtime.GOOS == "windows" {
+		// QEMU for Windows does not support 9p
+		mountTypesUnsupported[NINEP] = struct{}{}
+	}
+
 	// MountType has to be resolved before resolving Mounts
 	if y.MountType == nil {
 		y.MountType = d.MountType
@@ -944,7 +930,7 @@ func executeGuestTemplate(format, instDir string, user User, param map[string]st
 		name := filepath.Base(instDir)
 		data := map[string]any{
 			"Name":     name,
-			"Hostname": identifierutil.HostnameFromInstName(name), // TODO: support customization
+			"Hostname": hostname.FromInstName(name), // TODO: support customization
 			"UID":      *user.UID,
 			"User":     *user.Name,
 			"Home":     *user.Home,
