@@ -9,9 +9,10 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/sirupsen/logrus"
+
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
-	"github.com/sirupsen/logrus"
 )
 
 // Load loads the yaml and fulfills unspecified fields with the default values.
@@ -62,7 +63,7 @@ func load(b []byte, filePath string, warn bool) (*LimaYAML, error) {
 	}
 
 	// It should be called before the `y` parameter is passed to FillDefault() that execute template.
-	if err := ValidateParamIsUsed(&y); err != nil {
+	if err := validateParamIsUsed(&y); err != nil {
 		return nil, err
 	}
 
