@@ -16,7 +16,7 @@ import (
 // UnixPathMax is the value of UNIX_PATH_MAX.
 const UnixPathMax = 108
 
-// Stat is a selection of syscall.Stat_t
+// Stat is a selection of syscall.Stat_t.
 type Stat struct {
 	Uid uint32
 	Gid uint32
@@ -38,8 +38,8 @@ func SysKill(pid int, _ Signal) error {
 	return windows.GenerateConsoleCtrlEvent(syscall.CTRL_BREAK_EVENT, uint32(pid))
 }
 
-func Dup2(oldfd int, newfd syscall.Handle) (err error) {
-	return fmt.Errorf("unimplemented")
+func Dup2(_ int, _ syscall.Handle) error {
+	return errors.New("unimplemented")
 }
 
 func SignalName(sig os.Signal) string {
@@ -53,6 +53,6 @@ func SignalName(sig os.Signal) string {
 	}
 }
 
-func Sysctl(name string) (string, error) {
+func Sysctl(_ string) (string, error) {
 	return "", errors.New("sysctl: unimplemented on Windows")
 }
