@@ -19,14 +19,15 @@ import (
 	"time"
 
 	"github.com/docker/go-units"
+	"github.com/sirupsen/logrus"
+
 	hostagentclient "github.com/lima-vm/lima/pkg/hostagent/api/client"
-	"github.com/lima-vm/lima/pkg/identifierutil"
+	"github.com/lima-vm/lima/pkg/instance/hostname"
 	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/lima-vm/lima/pkg/store/dirnames"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/lima-vm/lima/pkg/textutil"
 	"github.com/lima-vm/lima/pkg/version/versionutil"
-	"github.com/sirupsen/logrus"
 )
 
 type Status = string
@@ -73,7 +74,7 @@ func Inspect(instName string) (*Instance, error) {
 	inst := &Instance{
 		Name: instName,
 		// TODO: support customizing hostname
-		Hostname: identifierutil.HostnameFromInstName(instName),
+		Hostname: hostname.FromInstName(instName),
 		Status:   StatusUnknown,
 	}
 	// InstanceDir validates the instName but does not check whether the instance exists
